summaryrefslogtreecommitdiffhomepage
path: root/public
diff options
context:
space:
mode:
authorAmlal El Mahrouss <amlal@nekernel.org>2025-10-26 12:29:35 +0100
committerAmlal El Mahrouss <amlal@nekernel.org>2025-10-26 12:30:34 +0100
commitb6ce6640afaf6c1cc6ad274f3053b2e218a49554 (patch)
tree69f6a0c6f08ef5ef2f6fcbb7302537dbce222e6e /public
parent744e9aba579a51dcab8f78009cbc091ce3cd8503 (diff)
feat: refactor HeFS to OpenHeFS.
Signed-off-by: Amlal El Mahrouss <amlal@nekernel.org>
Diffstat (limited to 'public')
-rw-r--r--public/frameworks/DiskImage.fwrk/headers/DiskImage.h2
-rw-r--r--public/frameworks/DiskImage.fwrk/src/DiskImage+HeFS.cc6
-rw-r--r--public/manuals/nekernel/mgmt.hefs.util.man6
3 files changed, 7 insertions, 7 deletions
diff --git a/public/frameworks/DiskImage.fwrk/headers/DiskImage.h b/public/frameworks/DiskImage.fwrk/headers/DiskImage.h
index 4a18b079..198d64a1 100644
--- a/public/frameworks/DiskImage.fwrk/headers/DiskImage.h
+++ b/public/frameworks/DiskImage.fwrk/headers/DiskImage.h
@@ -52,7 +52,7 @@ SInt32 DIFormatPartitionEPM(struct DI_DISK_IMAGE& img) noexcept;
/// @return Status code upon completion.
SInt32 DIFormatFilesystemNeFS(struct DI_DISK_IMAGE& img) noexcept;
-/// @brief HeFS format over EPM.
+/// @brief OpenHeFS format over EPM.
/// @param img disk image structure.
/// @return Status code upon completion.
SInt32 DIFormatFilesystemHeFS(struct DI_DISK_IMAGE& img) noexcept;
diff --git a/public/manuals/nekernel/mgmt.hefs.util.man b/public/manuals/nekernel/mgmt.hefs.util.man
index 3274f93a..1cb7022d 100644
--- a/public/manuals/nekernel/mgmt.hefs.util.man
+++ b/public/manuals/nekernel/mgmt.hefs.util.man
@@ -1,12 +1,12 @@
NAME
- mgmt.hefs — HeFS Management utility command
+ mgmt.hefs — OpenHeFS Management utility command
SYNOPSIS
mgmt.hefs [OPTIONS]
DESCRIPTION
The `mgmt.hefs` command provides scheduling, execution, and remote orchestration
- of a HeFS volume inside a System One environement. One might use this tool to
+ of a OpenHeFS volume inside a System One environement. One might use this tool to
create, edit, and remove volumes from a disk.
Usages include, but are not limited to:
@@ -16,7 +16,7 @@ DESCRIPTION
OPTIONS
-v, --volume <DEVICE> Device input
- -c, --create Create HeFS volume
+ -c, --create Create OpenHeFS volume
-x, --xml <PLIST> Pass PropertyList to volume creation tool.
-t, --time <HH:MMAM/PM> Time to run the script
-d, --day <DAY> Day of the week (e.g., Mon, Tue, Wed)
diff --git a/public/frameworks/DiskImage.fwrk/src/DiskImage+HeFS.cc b/public/frameworks/DiskImage.fwrk/src/DiskImage+HeFS.cc
index 7f917052..aa7abdf4 100644
--- a/public/frameworks/DiskImage.fwrk/src/DiskImage+HeFS.cc
+++ b/public/frameworks/DiskImage.fwrk/src/DiskImage+HeFS.cc
@@ -2,17 +2,17 @@
Copyright (C) 2025, Amlal El Mahrouss, all rights reserved.
- FILE: DiskImage+HeFS.cc
+ FILE: DiskImage+OpenHeFS.cc
PURPOSE: Disk Imaging framework.
------------------------------------------- */
#include <DiskImage.fwrk/headers/DiskImage.h>
-#include <FSKit/HeFS.h>
+#include <FSKit/OpenHeFS.h>
#include <FirmwareKit/EPM.h>
/// @brief format HeFS over an EPM disk.
/// @param img disk image structure.
/// @return Status code upon completion.
SInt32 DI::DIFormatFilesystemHeFS(struct DI_DISK_IMAGE& img) noexcept {
@@ -2,17 +2,17 @@
#include <FirmwareKit/EPM.h>
-/// @brief format HeFS over an EPM disk.
+/// @brief format OpenHeFS over an EPM disk.
/// @param img disk image structure.
/// @return Status code upon completion.